
declare namespace LRTS {

    export namespace globals {

        export namespace callbacks {

            /**
             * For only success or failure result callback.
             */
            export interface BooleanCallback {

                (err?: Error): void;
            }

            /**
             * For result and data callback.
             */
            export interface ResultCallback {

                (err: Error, data: any): void;
            }
        }
    }

    export namespace utils {

        export namespace loggers {

            export interface LogWriter {

                (logText: string, cb?: globals.callbacks.BooleanCallback): void;
                (logData: { [key: string]: string }, cb?: globals.callbacks.BooleanCallback): void;
            }

            export interface Logger {

                /**
                 * The default log type.
                 */
                defaultType: string;

                /**
                 * Register the writer function for a new log type
                 */
                registerType(logType: string, logWriter: LogWriter): void;

                /**
                 * Write a log in async mode.
                 */
                log(logText: string, logType?: string, cb?: globals.callbacks.BooleanCallback): void;

                /**
                 * Write a log in sync mode.
                 */
                logSync(logText: string, logType?: string);

            }

            export interface LoggerBase_Instance {

                "logWriters": { [logType: string]: LogWriter };

                "defType": string;

                registerType(logType: string, logWriter: LogWriter): void;

            }

            export interface LoggerBase_Static {
                new (): LoggerBase_Instance;
            }

            export interface Logger_Static {
                new (): Logger;
            }

        }
    }

}

declare module "lrts.globals" {

    import globals = LRTS.globals;
    export = globals;
}

declare module "lrts.utils.loggers" {

    export let LoggerBase: LRTS.utils.loggers.LoggerBase_Static;
    export let ConsoleLogger: LRTS.utils.loggers.Logger_Static;
    export import Logger = LRTS.utils.loggers.Logger;
}

declare module "lrts.utils" {

    export import loggers = require("lrts.utils.loggers");
}

declare module "lrts" {

    export import utils = require("lrts.utils");
    export import globals = require("lrts.globals");
}
