
import { BooleanCallback } from "../../common/callbacks";
import * as loggers from "./defines";

/**
 * The logger that write logs into console.
 */
class ConsoleLogger extends loggers.LoggerBase implements loggers.Logger {

    public constructor() {

        super();

        this.logWriters = {};
    }

    public log(logText: string, logType?: string, cb?: BooleanCallback): void {

        let writer: loggers.LogWriter;

        if (!logType) {

            logType = this.defType;
        }

        if (writer = this.logWriters[logType]) {

            writer(logText, cb);

        } else {

            cb && cb({
                "name": "BAD-LOG-TYPE",
                "message": "Specific log writer is not found."
            });
        }

    }

    public logSync(logText: string, logType?: string): void {

        let writer: loggers.LogWriter;

        if (!logType) {

            logType = this.defType;
        }

        if (writer = this.logWriters[logType]) {

            writer(logText, void 0);

        } else {

            throw {
                "name": "BAD-LOG-TYPE",
                "message": "Specific log writer is not found."
            };
        }

    }
}

export = ConsoleLogger;
