
import * as callbacks from "../../common/callbacks";

export interface LogWriter {

    (logText: string, cb?: callbacks.BooleanCallback): void;
    (logData: { [key: string]: string }, cb?: callbacks.BooleanCallback): void;
}

export interface Logger {

    /**
     * The default log type.
     */
    defaultType: string;

    /**
     * Register the writer function for a new log type
     */
    registerType(logType: string, logWriter: LogWriter): void;

    /**
     * Write a log in async mode.
     */
    log(logText: string, logType?: string, cb?: callbacks.BooleanCallback): void;

    /**
     * Write a log in sync mode.
     */
    logSync(logText: string, logType?: string);

}

export class LoggerBase {

    protected logWriters: { [logType: string]: LogWriter };

    protected defType: string;

    public registerType(logType: string, logWriter: LogWriter): void {

        this.logWriters[logType] = logWriter;

    }

    public set defaultType(newValue: string) {

        this.defType = newValue;
    }

    public get defaultType(): string {

        return this.defType;
    }
}
